// java wrapper for vtkTemporalSnapToTimeStep object
//

package vtk;
import vtk.*;

public class vtkTemporalSnapToTimeStep extends vtkPassInputTypeAlgorithm
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetSnapMode_2(int id0);
  public void SetSnapMode(int id0)
    { SetSnapMode_2(id0); }

  private native int GetSnapMode_3();
  public int GetSnapMode()
    { return GetSnapMode_3(); }

  private native void SetSnapModeToNearest_4();
  public void SetSnapModeToNearest()
    { SetSnapModeToNearest_4(); }

  private native void SetSnapModeToNextBelowOrEqual_5();
  public void SetSnapModeToNextBelowOrEqual()
    { SetSnapModeToNextBelowOrEqual_5(); }

  private native void SetSnapModeToNextAboveOrEqual_6();
  public void SetSnapModeToNextAboveOrEqual()
    { SetSnapModeToNextAboveOrEqual_6(); }

  public vtkTemporalSnapToTimeStep() { super(); }

  public vtkTemporalSnapToTimeStep(long id) { super(id); }
  public native long   VTKInit();

}
